@@ -30,7 +30,7 @@ class TestGenerator(object):
         self.xgenerator = ExecutableGenerator(parser, libraryroot)
         self.rerun = rerun
 
-        self.dependfiles = [ "timing.c", "timing.h", "timing.o", "fortpy.f90", 
+        self.dependfiles = [ "timing.c", "timing.h", "fortpy.f90", 
                              "Makefile.ifort", "Makefile.gfortran" ]
         self._fortpy = fortpy_templates
 
